import React, { useEffect, useState } from 'react'

/**
 * 提前设置主题的场景 changeTheme('light')
 */
import './stories'

import SwitchThemeCSSModuleComponent, { Component2 as SwitchThemeCSSModuleComponent2 } from '../examples/CSSModule/Component'
import SwitchThemePlainCSSComponent from '../examples/PlainCSS/Component'
import SwitchThemeCombinedCSSModuleComponent from '../examples/CombinedCSSModule/Component'
import SwitchThemeCombinedPlainCSSComponent from '../examples/CombinedPlainCSS/Component'
import {
  changeTheme,
  currentTheme, IEventData, offThemeChange, onThemeChange, ThemeProvider,
  ThemeSwitch,
  useThemeProvider
} from '../index'
import { MyEvent } from 'sunny-js/util/DOMEvent'

/**
 * 随后设置主题的场景 changeTheme('light')
 */
// changeTheme('light')

function toggleTheme () {
  return currentTheme() !== 'dark' ? 'dark' : 'light'
}

function NormalButton() {
  const [theme, setTheme] = useState(currentTheme())
  return <button onClick={() => {
    changeTheme(toggleTheme(), {
      onLoading() {
        console.log('主题加载中')
      },
      onSuccess() {
        console.log('主题已经切换至' + currentTheme())
        setTheme(currentTheme())
      },
      onError() {
        console.error('主题加载失败')
      }
    })
  }}>
    {theme} theme
  </button>
}

function ThemeSwitchButton() {
  return <ThemeSwitch
    onLoading={() => console.log('主题加载中')}
    onSuccess={() => console.log('主题已经切换至' + currentTheme())}
    onError={() => console.error('主题加载失败')}
  >{({ change, loading }) => {
    return <button
      onClick={() => change(toggleTheme())}
    >{loading ? 'loading' : currentTheme()} theme</button>
  }}</ThemeSwitch>
}

function CurrentTheme() {
  const theme = useThemeProvider()
  return <p>useThemeProvider {theme}</p>
}

function CurrentTheme2() {
  return <ThemeProvider>{theme => <p>ThemeProvider {theme}</p>}</ThemeProvider>
}

export default function Example () {
  // Event API用例
  useEffect(() => {
    const _onChange = (e: MyEvent<IEventData>) => {
      console.log(`Event API用例：当前主题已经切换至${e.data.theme}`)
    }
    onThemeChange(_onChange)
    return () => offThemeChange(_onChange)
  }, [])

  return <div data-page="SwitchTheme">
    <p>Normal Button: <NormalButton/></p>
    <p>ThemeSwitch Button: <ThemeSwitchButton/></p>
    <SwitchThemeCSSModuleComponent />
    <SwitchThemeCSSModuleComponent2 />
    <SwitchThemePlainCSSComponent />
    <SwitchThemeCombinedCSSModuleComponent />
    <SwitchThemeCombinedPlainCSSComponent />
    <CurrentTheme/>
    <CurrentTheme2/>
  </div>
}
